<?php

$LANG = array(

#header.php
'MENU'					=> 'Menu',
'HOME'					=> 'Home',
'GOTO_CONTENT'			=> 'Ga naar inhoud',
'GOTO_MENU'				=> 'Ga naar menu',
'COMMENTS_RSS_FEEDS'	=> 'RSS van de commentaren',
'COMMENTS'				=> 'Commentaren',
'ARTICLES_RSS_FEEDS'	=> 'RSS van de artikels',
'ARTICLES'				=> 'Artikels',

# sidebar.php
'CATEGORIES' 			=> 'Categorieën',
'LATEST_ARTICLES'		=> 'Laatste artikels',
'LATEST_COMMENTS'		=> 'Laatste commentaren',
'ARCHIVES'				=> 'Archief',

# footer.php
'POWERED_BY'			=> 'Aangemaakt met',
'PLUXML_DESCRIPTION'	=> 'Blog of Cms zonder databank',
'IN'					=> 'in',
'ADMINISTRATION'		=> 'Administratie',
'GOTO_TOP'				=> 'Ga naar top pagina',
'TOP'					=> 'Top pagina',

# erreur.php
'ERROR'					=> 'Er heeft zich een fout voorgedaan',
'BACKTO_HOME'			=> 'Terug naar onthaalpagina',

# common
'WRITTEN_BY'			=> 'Geschreven door',
'CLASSIFIED_IN'			=> 'Geklasseerd in',
'TAGS'					=> 'Sleutelwoorden',

# commentaires.php
'SAID'					=> 'zei',
'WRITE_A_COMMENT'		=> 'commentaar achterlaten',
'NAME'					=> 'Naam',
'WEBSITE'				=> 'Site (facultatief)',
'EMAIL'					=> 'E-mail (facultatief)',
'COMMENT'				=> 'Commentaar',
'CLEAR'					=> 'Wissen',
'SEND'					=> 'Verzenden',
'COMMENTS_CLOSED'		=> 'Commentaren zijn afgesloten',
'ANTISPAM_WARNING'		=> 'Anti-spam verificatie',

'REPLY'					=> 'Antwoord',
'REPLY_TO'				=> 'Antwoord',
'CANCEL'				=> 'Annuleren',

);

?>